@@ -15,4 +15,8 @@ async fn main () {
   let t: serde_json::Value = c.run_combine_function("checkCredentials", combine::CombineArguments::new().push("nqDjVRYV").push("123456")).await;
 
   println!("{:?}", t);
+}
+
+pub fn test () {
+  println!("test")
 }
\ No newline at end of file
